@@ -13,7 +13,7 @@ ICO_URL = (
 DEFAULT_GAME_SIZE = 4
 INVITE_LINK = (
     "https://discordapp.com/api/oauth2/authorize"
-    "?client_id=725510263251402832&permissions=93265&scope=bot"
+    "?client_id=725510263251402832&permissions=268528721&scope=bot"
 )
 VOTE_LINK = "https://top.gg/bot/725510263251402832/vote"
 
@@ -22,7 +22,10 @@ EMOJI_FAIL = "❌"
 EMOJI_JOIN_GAME = "✋"
 EMOJI_OK = "✅"
 
+DEFAULT_PREFIX = "!"
+
 VOICE_CATEGORY_PREFIX = "SpellBot Voice Channels"
 
-VOICE_INVITE_EXPIRE_TIME_S = 600  # ten minutes, make this configurable?
+VOICE_INVITE_EXPIRE_TIME_S = 14400  # 4 hours, make this configurable?
 CLEAN_S = 7  # seconds before temporary messages by the bot get cleaned up, configurable?
+REALLY_OLD_GAMES_HOURS = 5  # hours passed before game is considered really old
